@@ -162,6 +162,7 @@ class BoletoData(object):
         self.sacado_endereco = kwargs.pop('sacado_endereco', "")
         self.sacado_bairro = kwargs.pop('sacado_bairro', "")
         self.sacado_cep = kwargs.pop('sacado_cep', "")
+        self.linha_digitavel = kwargs.pop('linha_digitavel', "")
         if kwargs:
             raise TypeError("Paramêtro(s) desconhecido: %r" % (kwargs, ))
         self._cedente_endereco = None
@@ -171,62 +172,75 @@ class BoletoData(object):
         self._valor = None
         self._valor_documento = None
 
+    # @property
+    # def barcode(self):
+    #     """Essa função sempre é a mesma para todos os bancos. Então basta
+    #     implementar o método :func:`barcode` para o pyboleto calcular a linha
+    #     digitável.
+    #
+    #     Posição  #   Conteúdo
+    #     01 a 03  03  Número do banco
+    #     04       01  Código da Moeda - 9 para Real
+    #     05       01  Digito verificador do Código de Barras
+    #     06 a 09  04  Data de vencimento em dias partis de 07/10/1997
+    #     10 a 19  10  Valor do boleto (8 inteiros e 2 decimais)
+    #     20 a 44  25  Campo Livre definido por cada banco
+    #     Total    44
+    #     """
+    #
+    #     for attr, length, data_type in [
+    #             ('codigo_banco', 3, str),
+    #             ('moeda', 1, str),
+    #             ('data_vencimento', None, datetime.date),
+    #             ('valor_documento', -1, str),
+    #             ('campo_livre', 25, str)]:
+    #         value = getattr(self, attr)
+    #         if not isinstance(value, data_type):
+    #             raise TypeError("%s.%s must be a %s, got %r (type %s)" % (
+    #                 self.__class__.__name__, attr, data_type.__name__, value,
+    #                 type(value).__name__))
+    #         if (data_type == str and
+    #                 length != -1 and
+    #                 len(value) != length):
+    #             raise ValueError(
+    #                 "%s.%s must have a length of %d, not %r (len: %d)" %
+    #                 (self.__class__.__name__,
+    #                  attr,
+    #                  length,
+    #                  value,
+    #                  len(value)))
+    #
+    #     due_date_days = (self.data_vencimento - _EPOCH).days
+    #     if not (9999 >= due_date_days >= 0):
+    #         raise TypeError(
+    #             "Invalid date, must be between 1997/07/01 and "
+    #             "2024/11/15")
+    #     num = "%s%1s%04d%010d%24s" % (self.codigo_banco,
+    #                                   self.moeda,
+    #                                   due_date_days,
+    #                                   Decimal(self.valor_documento) * 100,
+    #                                   self.campo_livre)
+    #     dv = self.calculate_dv_barcode(num)
+    #
+    #     barcode = num[:4] + str(dv) + num[4:]
+    #     if len(barcode) != 44:
+    #         raise BoletoException(
+    #             'The barcode must have 44 characteres, found %d' %
+    #             len(barcode))
+    #     return barcode
+
     @property
     def barcode(self):
-        """Essa função sempre é a mesma para todos os bancos. Então basta
-        implementar o método :func:`barcode` para o pyboleto calcular a linha
-        digitável.
-
-        Posição  #   Conteúdo
-        01 a 03  03  Número do banco
-        04       01  Código da Moeda - 9 para Real
-        05       01  Digito verificador do Código de Barras
-        06 a 09  04  Data de vencimento em dias partis de 07/10/1997
-        10 a 19  10  Valor do boleto (8 inteiros e 2 decimais)
-        20 a 44  25  Campo Livre definido por cada banco
-        Total    44
-        """
-
-        for attr, length, data_type in [
-                ('codigo_banco', 3, str),
-                ('moeda', 1, str),
-                ('data_vencimento', None, datetime.date),
-                ('valor_documento', -1, str),
-                ('campo_livre', 25, str)]:
-            value = getattr(self, attr)
-            if not isinstance(value, data_type):
-                raise TypeError("%s.%s must be a %s, got %r (type %s)" % (
-                    self.__class__.__name__, attr, data_type.__name__, value,
-                    type(value).__name__))
-            if (data_type == str and
-                    length != -1 and
-                    len(value) != length):
-                raise ValueError(
-                    "%s.%s must have a length of %d, not %r (len: %d)" %
-                    (self.__class__.__name__,
-                     attr,
-                     length,
-                     value,
-                     len(value)))
-
-        due_date_days = (self.data_vencimento - _EPOCH).days
-        if not (9999 >= due_date_days >= 0):
-            raise TypeError(
-                "Invalid date, must be between 1997/07/01 and "
-                "2024/11/15")
-        num = "%s%1s%04d%010d%24s" % (self.codigo_banco,
-                                      self.moeda,
-                                      due_date_days,
-                                      Decimal(self.valor_documento) * 100,
-                                      self.campo_livre)
-        dv = self.calculate_dv_barcode(num)
-
-        barcode = num[:4] + str(dv) + num[4:]
-        if len(barcode) != 44:
-            raise BoletoException(
-                'The barcode must have 44 characteres, found %d' %
-                len(barcode))
-        return barcode
+        digitavel = self.linha_digitavel.replace('.', '').replace(' ', '')
+        partes = [
+            digitavel[0:4],
+            digitavel[32:47],
+            digitavel[4:9],
+            digitavel[10:16],
+            digitavel[16:20],
+            digitavel[21:31],
+        ]
+        return "".join(partes)
 
     @property
     def campo_livre(self):
@@ -429,13 +443,13 @@ class BoletoData(object):
         return cod
 
     @property
-    def linha_digitavel(self):
+    def linha_digitavel_formatada(self):
         """Monta a linha digitável a partir do barcode
 
         Esta é a linha que o cliente pode utilizar para digitar se o código
         de barras não estiver legível.
         """
-        linha = self.barcode
+        linha = self.linha_digitavel
         if not linha:
             raise BoletoException("Boleto doesn't have a barcode")
         return f"{linha[0:5]}.{linha[5:10]} {linha[10:15]}.{linha[15:21]} {linha[21:26]}.{linha[26:32]} {linha[32:33]} {linha[33:47]}"
