@@ -748,7 +748,7 @@ class BoletoPDF(object):
         self.pdf_canvas.drawRightString(
             self.width,
             y + 2 * self.space,
-            boleto_dados.linha_digitavel
+            boleto_dados.linha_digitavel_formatada
         )
 
         # Codigo de barras
